# SearchV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**result** | [**list[ResultV30Rc1]**](ResultV30Rc1.md) |  | [optional] 
**num_found** | **int** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

